@@ -31,12 +31,10 @@
 #include <QUuid>
 
 // KDE
-#include <klocalizedstring.h>
 #include <kconfig.h>
 #include <kconfiggroup.h>
 #include <ksharedconfig.h>
 #include <kfileitem.h>
-#include <kservice.h>
 #include <kdesktopfile.h>
 
 // STL and Boost
@@ -48,12 +46,13 @@
 #include <boost/range/adaptor/filtered.hpp>
 
 // Local
-#include "utils/continue_with.h"
 #include "utils/range.h"
-#include "utils/continue_with.h"
 #include "utils/dbusfuture_p.h"
 #include "common/dbus/common.h"
 
+#define ENABLE_QJSVALUE_CONTINUATION
+#include "utils/continue_with.h"
+
 #define ACTIVITY_COLUMN 0
 #define AGENT_COLUMN    1
 #define RESOURCE_COLUMN 2
@@ -68,7 +67,7 @@ namespace Imports {
 class ResourceModel::LinkerService: public QDBusInterface {
 private:
     LinkerService()
-        : KAMD_DBUS_INTERFACE(Resources/Linking, ResourcesLinking, Q_NULLPTR)
+        : KAMD_DBUS_INTERFACE(Resources/Linking, ResourcesLinking, nullptr)
     {
     }
 
@@ -87,7 +86,7 @@ public:
             s_instance = result;
         }
 
-        return std::move(result);
+        return result;
     }
 
 };
@@ -117,10 +116,10 @@ ResourceModel::ResourceModel(QObject *parent)
     connect(&m_service, &KActivities::Consumer::currentActivityChanged,
             this, &ResourceModel::onCurrentActivityChanged);
 
-    connect(m_linker.get(), SIGNAL(ResourceLinkedToActivity(QString, QString, QString)),
-            this, SLOT(onResourceLinkedToActivity(QString, QString, QString)));
-    connect(m_linker.get(), SIGNAL(ResourceUnlinkedFromActivity(QString, QString, QString)),
-            this, SLOT(onResourceUnlinkedFromActivity(QString, QString, QString)));
+    connect(m_linker.get(), SIGNAL(ResourceLinkedToActivity(QString,QString,QString)),
+            this, SLOT(onResourceLinkedToActivity(QString,QString,QString)));
+    connect(m_linker.get(), SIGNAL(ResourceUnlinkedFromActivity(QString,QString,QString)),
+            this, SLOT(onResourceUnlinkedFromActivity(QString,QString,QString)));
 
     setDynamicSortFilter(true);
     sort(0);
@@ -318,7 +317,7 @@ void ResourceModel::reloadData()
 
 void ResourceModel::onCurrentActivityChanged(const QString &activity)
 {
-    Q_UNUSED(activity)
+    Q_UNUSED(activity);
 
     if (m_shownActivities.contains(":current")) {
         reloadData();
@@ -517,7 +516,7 @@ void ResourceModel::onResourceLinkedToActivity(const QString &initiatingAgent,
                                                const QString &targettedResource,
                                                const QString &usedActivity)
 {
-    Q_UNUSED(targettedResource)
+    Q_UNUSED(targettedResource);
 
     if (!loadDatabase()) return;
 
